import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useMemo, useState } from 'react';
import { usePlotContext } from '../hooks';
import { getNextId, validateAxis } from '../utils';
import ScatterSeries from './ScatterSeries';
import { useLegend } from './legendsContext';
export default function BarSeries(props) {
    var _a;
    const [, legendDispatch] = useLegend();
    const { colorScaler } = usePlotContext();
    const [id] = useState(() => props.groupId || `series-${getNextId()}`);
    const { lineStyle = {}, displayMarker = false, ...otherProps } = props;
    const lineProps = {
        id,
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        lineStyle,
    };
    const colorLine = (lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke)
        ? lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke.toString()
        : colorScaler(id);
    const color = ((_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill.toString()) || colorScaler(id);
    const figure = otherProps.markerShape || 'circle';
    const shape = useMemo(() => {
        return {
            color,
            figure,
            hidden: !displayMarker,
        };
    }, [color, displayMarker, figure]);
    useEffect(() => {
        legendDispatch({
            type: 'ADD_LEGEND_LABEL',
            payload: {
                id,
                label: otherProps.label,
                colorLine,
                shape,
            },
        });
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [colorLine, legendDispatch, otherProps.label, shape, id]);
    return (_jsxs("g", { children: [props.hidden ? null : _jsx(BarSeriesRender, Object.assign({}, lineProps), void 0),
            _jsx(ScatterSeries, Object.assign({}, otherProps, { hidden: !displayMarker || props.hidden, groupId: id }), void 0)] }, void 0));
}
function BarSeriesRender({ id, data, xAxis, yAxis, lineStyle, }) {
    // Get scales from context
    const { axisContext, colorScaler } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, xAxis, yAxis);
    const color = colorScaler(id);
    if ([xScale, yScale].includes(undefined))
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return (_jsx("g", { children: data.map(({ x, y }) => (_jsx("line", { style: style, x1: xScale(x), x2: xScale(x), y1: yScale(y), y2: yScale(0) }, `${x}-${y}`))) }, void 0));
}
//# sourceMappingURL=BarSeries.js.map